# AIRPrediction

## Contributors
Daniel Casto, Colin Naehr, Derek Pena, and Haotian Wang

## Special Thanks
Yuko Matsumoto - Pitching the idea for AIRPrediction, forming Data for Good by UF, and performing extensive research into the Time Series Models (Prophet and ARIMA).

## Description
(Framework) AIR Quality Forecast Model leveraging Time Series Models to enable timely preventive measures to reduce harmful impact on U.S. citizens.

## Documentation Navigation
To find the documentation in man format of the features of this framework, utilize this navigation:
docs -> build -> html -> index.html

## Dataset Used to Train the Prediction Model
Since GitHub has a strict file limit of 100MB, we cannot upload the dataset to GitHub.
You need to include this csv file manually in the data folder, and it can be downloaded from this link: 
https://www.kaggle.com/sogun3/uspollution
pollution_us_2000_2016.csv(382.37 MB)

## Package Name for PIP Installation
`pip install AIRPrediction`


## Command to Run Sample App
`sampleapp`

## Repository Link
https://github.com/danielcasto/AIRPrediction
